[![Build Status](https://travis-ci.org/RustyBower/sopel-stocks.svg?branch=master)](https://travis-ci.org/RustyBower/sopel-stocks)
[![Maintainability](https://api.codeclimate.com/v1/badges/719931784d9152a50a09/maintainability)](https://codeclimate.com/github/RustyBower/sopel-stocks/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/719931784d9152a50a09/test_coverage)](https://codeclimate.com/github/RustyBower/sopel-stocks/test_coverage)
[![PyPI version](https://badge.fury.io/py/sopel-modules.stocks.svg)](https://badge.fury.io/py/sopel-modules.stocks)

# sopel-stocks
sopel-stocks is an stock lookup module for Sopel

## Usage
```
.stock djia
.stock msft
```